import type { Metadata } from "next";
import { Inter } from "next/font/google";
import "./globals.css";
import { ClientNavigation } from "@/components/navigation";
import Script from "next/script";

const inter = Inter({ subsets: ["latin"] });

export const metadata: Metadata = {
  title: "Naomi's Portfolio",
  description:
    "This page tells you everything you could ever want to know about Naomi and her consulting firm nhcarrigan.",
  openGraph: {
    images: "https://cdn.nhcarrigan.com/background.png",
  },
  twitter: {
    card: "summary_large_image",
    site: "@naomi_lgbt",
    images: "https://cdn.nhcarrigan.com/background.png",
  },
};

export default function RootLayout({
  children,
}: Readonly<{
  children: React.ReactNode;
}>) {
  return (
    <html lang="en">
      <link rel="icon" href="https://cdn.nhcarrigan.com/logo.png" sizes="any" />
      <body className={inter.className}>
        <header>
          <ClientNavigation />
        </header>
        {children}
        <video
          src="https://cdn.nhcarrigan.com/overlay.webm"
          autoPlay
          loop
          muted
          playsInline
          className="fixed top-0 left-0 w-full h-full object-cover opacity-25"
          style={{ pointerEvents: "none" }}
        />
      </body>
      <Script
        type="text/javascript"
        id="hs-script-loader"
        async
        defer
        src="//js.hs-scripts.com/47086586.js"
      ></Script>
    </html>
  );
}
